pub struct Area(/* private fields */);Expand description
Area in square meters.
Implementations
Sourceimpl Area
impl Area
Sourcepub const fn square_meters(m2: f64) -> Area
pub const fn square_meters(m2: f64) -> Area
Creates a new area from an f64 value in square meters.
Sourcepub const fn square_kilometers(km2: f64) -> Area
pub const fn square_kilometers(km2: f64) -> Area
Creates a new area from an f64 value in square kilometers.
Sourcepub const fn to_square_meters(&self) -> f64
pub const fn to_square_meters(&self) -> f64
Returns the value of the area in square meters.
Sourcepub const fn to_square_kilometers(&self) -> f64
pub const fn to_square_kilometers(&self) -> f64
Returns the value of the area in square kilometers.